For module_api sample, use vcpy_kernel.cu to generate ptx file for NV path.

Change-Id: Id0033678834288c4eaa56b12e7d447119be99deb
这个提交包含在:
pensun
2016-09-03 21:06:58 -05:00
父节点 6ca7a87e0e
当前提交 49971e8c9e
修改 2 个文件,包含 8 行新增2 行删除
+2 -2
查看文件
@@ -21,8 +21,8 @@ endif
ifeq (${HIP_PLATFORM}, nvcc)
vcpy_kernel.compile: vcpy_kernel.cpp
$(HIPCC) --genco vcpy_kernel.cpp -o vcpy_kernel.ptx
vcpy_kernel.compile: vcpy_kernel.cu
$(HIPCC) --genco vcpy_kernel.cu -o vcpy_kernel.ptx
clean:
rm -f *.ptx *.out
@@ -0,0 +1,6 @@
extern "C" __global__ void hello_world(float *a, float *b)
{
int tx = threadIdx.x;
b[tx] = a[tx];
}